# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['NodeArgs', 'Node']

@pulumi.input_type
class NodeArgs:
    def __init__(__self__, *,
                 cluster_id: pulumi.Input[builtins.str],
                 node_pool_id: pulumi.Input[builtins.str],
                 additional_container_storage_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 container_storage_path: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 initialize_script: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 keep_instance_name: Optional[pulumi.Input[builtins.bool]] = None,
                 kubernetes_config: Optional[pulumi.Input['NodeKubernetesConfigArgs']] = None):
        """
        The set of arguments for constructing a Node resource.
        :param pulumi.Input[builtins.str] cluster_id: 集群的 ID。
        :param pulumi.Input[builtins.str] node_pool_id: 节点池 ID。不传入参数值：表示将已有 ECS 实例添加到默认节点池。传入参数值：表示将已有 ECS 实例添加到自定义节点池。
        :param pulumi.Input[builtins.bool] additional_container_storage_enabled: 选择配置节点的数据盘并格式化挂载作为容器镜像和日志的存储目录，取值：false：（默认值）关闭。默认节点池：表示不挂载数据盘。自定义节点池：使用节点池的数据盘配置进行挂载，被添加到节点池的 ECS 实例数据盘必须包含目标节点池指定了挂载的数据盘（含本地盘），且盘类型和大小完全一致。true: 开启。此时必须同时配置 ContainerStoragePath 参数。节点通过 ContainerStoragePath参数中的配置进行挂载，而忽略节点池的数据盘配置，对被添加到节点池的 ECS 实例数据盘无特殊要求。
        :param pulumi.Input[builtins.str] container_storage_path: 使用该数据盘设备挂载容器和镜像存储目录/var/lib/containerd。
               仅当AdditionalContainerStorageEnabled=true时有效，且不能为空。须满足以下条件，否则将初始化失败：仅支持已挂载数据盘的 ECS 实例。指定数据盘设备名时，请确保该数据盘设备存在，否则会初始化失败。指定数据盘分区或逻辑卷名时，请确保该分区或逻辑卷存在，且为 ext4 文件系统。
        :param pulumi.Input[builtins.str] image_id: 节点对应的 ECS 实例使用的镜像 ID。
        :param pulumi.Input[builtins.str] initialize_script: 创建 ECS 节点并完成 Kubernetes 组件部署后执行的脚本。支持 Shell 格式，Base64 编码后长度不超过 1 KB。为空时，节点继承使用默认节点池配置的初始化脚本NodeConfig.InitializeScript。自定义填写脚本内容后，使用自定义的脚本，忽略默认节点池配置的初始化脚本。
        :param pulumi.Input[builtins.str] instance_id: 节点对应的云服务器实例 ID。
        :param pulumi.Input[builtins.bool] keep_instance_name: 是否保留原 ECS 实例名称，取值：false：（默认值）不保留原 ECS 实例名称，由容器服务自动为其命名。true：保留原 ECS 实例名称。
        :param pulumi.Input['NodeKubernetesConfigArgs'] kubernetes_config: 节点 Kubernetes 相关配置。为空时，节点继承使用默认节点池的 Kubernetes 配置KubernetesConfig.Labels/Taints/Cordon。自定义填写配置后，使用自定义配置内容，忽略默认节点池的 Kubernetes 配置。
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "node_pool_id", node_pool_id)
        if additional_container_storage_enabled is not None:
            pulumi.set(__self__, "additional_container_storage_enabled", additional_container_storage_enabled)
        if container_storage_path is not None:
            pulumi.set(__self__, "container_storage_path", container_storage_path)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if initialize_script is not None:
            pulumi.set(__self__, "initialize_script", initialize_script)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if keep_instance_name is not None:
            pulumi.set(__self__, "keep_instance_name", keep_instance_name)
        if kubernetes_config is not None:
            pulumi.set(__self__, "kubernetes_config", kubernetes_config)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Input[builtins.str]:
        """
        集群的 ID。
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="nodePoolId")
    def node_pool_id(self) -> pulumi.Input[builtins.str]:
        """
        节点池 ID。不传入参数值：表示将已有 ECS 实例添加到默认节点池。传入参数值：表示将已有 ECS 实例添加到自定义节点池。
        """
        return pulumi.get(self, "node_pool_id")

    @node_pool_id.setter
    def node_pool_id(self, value: pulumi.Input[builtins.str]):
        pulumi.set(self, "node_pool_id", value)

    @property
    @pulumi.getter(name="additionalContainerStorageEnabled")
    def additional_container_storage_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        选择配置节点的数据盘并格式化挂载作为容器镜像和日志的存储目录，取值：false：（默认值）关闭。默认节点池：表示不挂载数据盘。自定义节点池：使用节点池的数据盘配置进行挂载，被添加到节点池的 ECS 实例数据盘必须包含目标节点池指定了挂载的数据盘（含本地盘），且盘类型和大小完全一致。true: 开启。此时必须同时配置 ContainerStoragePath 参数。节点通过 ContainerStoragePath参数中的配置进行挂载，而忽略节点池的数据盘配置，对被添加到节点池的 ECS 实例数据盘无特殊要求。
        """
        return pulumi.get(self, "additional_container_storage_enabled")

    @additional_container_storage_enabled.setter
    def additional_container_storage_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "additional_container_storage_enabled", value)

    @property
    @pulumi.getter(name="containerStoragePath")
    def container_storage_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        使用该数据盘设备挂载容器和镜像存储目录/var/lib/containerd。
        仅当AdditionalContainerStorageEnabled=true时有效，且不能为空。须满足以下条件，否则将初始化失败：仅支持已挂载数据盘的 ECS 实例。指定数据盘设备名时，请确保该数据盘设备存在，否则会初始化失败。指定数据盘分区或逻辑卷名时，请确保该分区或逻辑卷存在，且为 ext4 文件系统。
        """
        return pulumi.get(self, "container_storage_path")

    @container_storage_path.setter
    def container_storage_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "container_storage_path", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点对应的 ECS 实例使用的镜像 ID。
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="initializeScript")
    def initialize_script(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建 ECS 节点并完成 Kubernetes 组件部署后执行的脚本。支持 Shell 格式，Base64 编码后长度不超过 1 KB。为空时，节点继承使用默认节点池配置的初始化脚本NodeConfig.InitializeScript。自定义填写脚本内容后，使用自定义的脚本，忽略默认节点池配置的初始化脚本。
        """
        return pulumi.get(self, "initialize_script")

    @initialize_script.setter
    def initialize_script(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "initialize_script", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点对应的云服务器实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="keepInstanceName")
    def keep_instance_name(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否保留原 ECS 实例名称，取值：false：（默认值）不保留原 ECS 实例名称，由容器服务自动为其命名。true：保留原 ECS 实例名称。
        """
        return pulumi.get(self, "keep_instance_name")

    @keep_instance_name.setter
    def keep_instance_name(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "keep_instance_name", value)

    @property
    @pulumi.getter(name="kubernetesConfig")
    def kubernetes_config(self) -> Optional[pulumi.Input['NodeKubernetesConfigArgs']]:
        """
        节点 Kubernetes 相关配置。为空时，节点继承使用默认节点池的 Kubernetes 配置KubernetesConfig.Labels/Taints/Cordon。自定义填写配置后，使用自定义配置内容，忽略默认节点池的 Kubernetes 配置。
        """
        return pulumi.get(self, "kubernetes_config")

    @kubernetes_config.setter
    def kubernetes_config(self, value: Optional[pulumi.Input['NodeKubernetesConfigArgs']]):
        pulumi.set(self, "kubernetes_config", value)


@pulumi.input_type
class _NodeState:
    def __init__(__self__, *,
                 additional_container_storage_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 container_storage_path: Optional[pulumi.Input[builtins.str]] = None,
                 created_time: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 initialize_script: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 is_virtual: Optional[pulumi.Input[builtins.bool]] = None,
                 keep_instance_name: Optional[pulumi.Input[builtins.bool]] = None,
                 kubernetes_config: Optional[pulumi.Input['NodeKubernetesConfigArgs']] = None,
                 name: Optional[pulumi.Input[builtins.str]] = None,
                 node_id: Optional[pulumi.Input[builtins.str]] = None,
                 node_pool_id: Optional[pulumi.Input[builtins.str]] = None,
                 roles: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 status: Optional[pulumi.Input['NodeStatusArgs']] = None,
                 updated_time: Optional[pulumi.Input[builtins.str]] = None,
                 zone_id: Optional[pulumi.Input[builtins.str]] = None):
        """
        Input properties used for looking up and filtering Node resources.
        :param pulumi.Input[builtins.bool] additional_container_storage_enabled: 选择配置节点的数据盘并格式化挂载作为容器镜像和日志的存储目录，取值：false：（默认值）关闭。默认节点池：表示不挂载数据盘。自定义节点池：使用节点池的数据盘配置进行挂载，被添加到节点池的 ECS 实例数据盘必须包含目标节点池指定了挂载的数据盘（含本地盘），且盘类型和大小完全一致。true: 开启。此时必须同时配置 ContainerStoragePath 参数。节点通过 ContainerStoragePath参数中的配置进行挂载，而忽略节点池的数据盘配置，对被添加到节点池的 ECS 实例数据盘无特殊要求。
        :param pulumi.Input[builtins.str] cluster_id: 集群的 ID。
        :param pulumi.Input[builtins.str] container_storage_path: 使用该数据盘设备挂载容器和镜像存储目录/var/lib/containerd。
               仅当AdditionalContainerStorageEnabled=true时有效，且不能为空。须满足以下条件，否则将初始化失败：仅支持已挂载数据盘的 ECS 实例。指定数据盘设备名时，请确保该数据盘设备存在，否则会初始化失败。指定数据盘分区或逻辑卷名时，请确保该分区或逻辑卷存在，且为 ext4 文件系统。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] image_id: 节点对应的 ECS 实例使用的镜像 ID。
        :param pulumi.Input[builtins.str] initialize_script: 创建 ECS 节点并完成 Kubernetes 组件部署后执行的脚本。支持 Shell 格式，Base64 编码后长度不超过 1 KB。为空时，节点继承使用默认节点池配置的初始化脚本NodeConfig.InitializeScript。自定义填写脚本内容后，使用自定义的脚本，忽略默认节点池配置的初始化脚本。
        :param pulumi.Input[builtins.str] instance_id: 节点对应的云服务器实例 ID。
        :param pulumi.Input[builtins.bool] is_virtual: 是否为虚拟节点，参数值说明：false：否 true：是。
        :param pulumi.Input[builtins.bool] keep_instance_name: 是否保留原 ECS 实例名称，取值：false：（默认值）不保留原 ECS 实例名称，由容器服务自动为其命名。true：保留原 ECS 实例名称。
        :param pulumi.Input['NodeKubernetesConfigArgs'] kubernetes_config: 节点 Kubernetes 相关配置。为空时，节点继承使用默认节点池的 Kubernetes 配置KubernetesConfig.Labels/Taints/Cordon。自定义填写配置后，使用自定义配置内容，忽略默认节点池的 Kubernetes 配置。
        :param pulumi.Input[builtins.str] name: 节点名称。
        :param pulumi.Input[builtins.str] node_id: 节点 ID。
        :param pulumi.Input[builtins.str] node_pool_id: 节点池 ID。不传入参数值：表示将已有 ECS 实例添加到默认节点池。传入参数值：表示将已有 ECS 实例添加到自定义节点池。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] roles: 节点角色，参数值说明：Worker：Worker节点。
        :param pulumi.Input['NodeStatusArgs'] status: 节点状态。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] zone_id: 可用区 ID。
        """
        if additional_container_storage_enabled is not None:
            pulumi.set(__self__, "additional_container_storage_enabled", additional_container_storage_enabled)
        if cluster_id is not None:
            pulumi.set(__self__, "cluster_id", cluster_id)
        if container_storage_path is not None:
            pulumi.set(__self__, "container_storage_path", container_storage_path)
        if created_time is not None:
            pulumi.set(__self__, "created_time", created_time)
        if image_id is not None:
            pulumi.set(__self__, "image_id", image_id)
        if initialize_script is not None:
            pulumi.set(__self__, "initialize_script", initialize_script)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if is_virtual is not None:
            pulumi.set(__self__, "is_virtual", is_virtual)
        if keep_instance_name is not None:
            pulumi.set(__self__, "keep_instance_name", keep_instance_name)
        if kubernetes_config is not None:
            pulumi.set(__self__, "kubernetes_config", kubernetes_config)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if node_id is not None:
            pulumi.set(__self__, "node_id", node_id)
        if node_pool_id is not None:
            pulumi.set(__self__, "node_pool_id", node_pool_id)
        if roles is not None:
            pulumi.set(__self__, "roles", roles)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if updated_time is not None:
            pulumi.set(__self__, "updated_time", updated_time)
        if zone_id is not None:
            pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="additionalContainerStorageEnabled")
    def additional_container_storage_enabled(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        选择配置节点的数据盘并格式化挂载作为容器镜像和日志的存储目录，取值：false：（默认值）关闭。默认节点池：表示不挂载数据盘。自定义节点池：使用节点池的数据盘配置进行挂载，被添加到节点池的 ECS 实例数据盘必须包含目标节点池指定了挂载的数据盘（含本地盘），且盘类型和大小完全一致。true: 开启。此时必须同时配置 ContainerStoragePath 参数。节点通过 ContainerStoragePath参数中的配置进行挂载，而忽略节点池的数据盘配置，对被添加到节点池的 ECS 实例数据盘无特殊要求。
        """
        return pulumi.get(self, "additional_container_storage_enabled")

    @additional_container_storage_enabled.setter
    def additional_container_storage_enabled(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "additional_container_storage_enabled", value)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        集群的 ID。
        """
        return pulumi.get(self, "cluster_id")

    @cluster_id.setter
    def cluster_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "cluster_id", value)

    @property
    @pulumi.getter(name="containerStoragePath")
    def container_storage_path(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        使用该数据盘设备挂载容器和镜像存储目录/var/lib/containerd。
        仅当AdditionalContainerStorageEnabled=true时有效，且不能为空。须满足以下条件，否则将初始化失败：仅支持已挂载数据盘的 ECS 实例。指定数据盘设备名时，请确保该数据盘设备存在，否则会初始化失败。指定数据盘分区或逻辑卷名时，请确保该分区或逻辑卷存在，且为 ext4 文件系统。
        """
        return pulumi.get(self, "container_storage_path")

    @container_storage_path.setter
    def container_storage_path(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "container_storage_path", value)

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @created_time.setter
    def created_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "created_time", value)

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点对应的 ECS 实例使用的镜像 ID。
        """
        return pulumi.get(self, "image_id")

    @image_id.setter
    def image_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "image_id", value)

    @property
    @pulumi.getter(name="initializeScript")
    def initialize_script(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        创建 ECS 节点并完成 Kubernetes 组件部署后执行的脚本。支持 Shell 格式，Base64 编码后长度不超过 1 KB。为空时，节点继承使用默认节点池配置的初始化脚本NodeConfig.InitializeScript。自定义填写脚本内容后，使用自定义的脚本，忽略默认节点池配置的初始化脚本。
        """
        return pulumi.get(self, "initialize_script")

    @initialize_script.setter
    def initialize_script(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "initialize_script", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点对应的云服务器实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="isVirtual")
    def is_virtual(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否为虚拟节点，参数值说明：false：否 true：是。
        """
        return pulumi.get(self, "is_virtual")

    @is_virtual.setter
    def is_virtual(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "is_virtual", value)

    @property
    @pulumi.getter(name="keepInstanceName")
    def keep_instance_name(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否保留原 ECS 实例名称，取值：false：（默认值）不保留原 ECS 实例名称，由容器服务自动为其命名。true：保留原 ECS 实例名称。
        """
        return pulumi.get(self, "keep_instance_name")

    @keep_instance_name.setter
    def keep_instance_name(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "keep_instance_name", value)

    @property
    @pulumi.getter(name="kubernetesConfig")
    def kubernetes_config(self) -> Optional[pulumi.Input['NodeKubernetesConfigArgs']]:
        """
        节点 Kubernetes 相关配置。为空时，节点继承使用默认节点池的 Kubernetes 配置KubernetesConfig.Labels/Taints/Cordon。自定义填写配置后，使用自定义配置内容，忽略默认节点池的 Kubernetes 配置。
        """
        return pulumi.get(self, "kubernetes_config")

    @kubernetes_config.setter
    def kubernetes_config(self, value: Optional[pulumi.Input['NodeKubernetesConfigArgs']]):
        pulumi.set(self, "kubernetes_config", value)

    @property
    @pulumi.getter
    def name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点名称。
        """
        return pulumi.get(self, "name")

    @name.setter
    def name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "name", value)

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点 ID。
        """
        return pulumi.get(self, "node_id")

    @node_id.setter
    def node_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_id", value)

    @property
    @pulumi.getter(name="nodePoolId")
    def node_pool_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        节点池 ID。不传入参数值：表示将已有 ECS 实例添加到默认节点池。传入参数值：表示将已有 ECS 实例添加到自定义节点池。
        """
        return pulumi.get(self, "node_pool_id")

    @node_pool_id.setter
    def node_pool_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "node_pool_id", value)

    @property
    @pulumi.getter
    def roles(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        节点角色，参数值说明：Worker：Worker节点。
        """
        return pulumi.get(self, "roles")

    @roles.setter
    def roles(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "roles", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input['NodeStatusArgs']]:
        """
        节点状态。
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input['NodeStatusArgs']]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @updated_time.setter
    def updated_time(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "updated_time", value)

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        可用区 ID。
        """
        return pulumi.get(self, "zone_id")

    @zone_id.setter
    def zone_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "zone_id", value)


@pulumi.type_token("bytepluscc:vke/node:Node")
class Node(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_container_storage_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 container_storage_path: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 initialize_script: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 keep_instance_name: Optional[pulumi.Input[builtins.bool]] = None,
                 kubernetes_config: Optional[pulumi.Input[Union['NodeKubernetesConfigArgs', 'NodeKubernetesConfigArgsDict']]] = None,
                 node_pool_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        """
        对应 Kubernetes 中的 Node，是容器服务集群组成的基本元素。节点主要包括：Master 节点（控制节点）和 Worker 节点（计算节点/工作节点）。应用实际部署在 Worker 节点上，支持通过配置随机部署在 Worker 节点上或部署在指定的 Worker 节点上。容器服务中的 节点 一般指 Worker 节点。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vke_node_demo = bytepluscc.vke.Node("VkeNodeDemo",
            additional_container_storage_enabled=False,
            cluster_id="cd5rdfs5ixxxxxotsc2g",
            container_storage_path="",
            instance_id="i-yeekjuixxxxx4je5vfr",
            keep_instance_name=True,
            node_pool_id="pd5s9srqxxxxxo88e621g")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/node:Node example "cluster_id|node_pool_id|node_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] additional_container_storage_enabled: 选择配置节点的数据盘并格式化挂载作为容器镜像和日志的存储目录，取值：false：（默认值）关闭。默认节点池：表示不挂载数据盘。自定义节点池：使用节点池的数据盘配置进行挂载，被添加到节点池的 ECS 实例数据盘必须包含目标节点池指定了挂载的数据盘（含本地盘），且盘类型和大小完全一致。true: 开启。此时必须同时配置 ContainerStoragePath 参数。节点通过 ContainerStoragePath参数中的配置进行挂载，而忽略节点池的数据盘配置，对被添加到节点池的 ECS 实例数据盘无特殊要求。
        :param pulumi.Input[builtins.str] cluster_id: 集群的 ID。
        :param pulumi.Input[builtins.str] container_storage_path: 使用该数据盘设备挂载容器和镜像存储目录/var/lib/containerd。
               仅当AdditionalContainerStorageEnabled=true时有效，且不能为空。须满足以下条件，否则将初始化失败：仅支持已挂载数据盘的 ECS 实例。指定数据盘设备名时，请确保该数据盘设备存在，否则会初始化失败。指定数据盘分区或逻辑卷名时，请确保该分区或逻辑卷存在，且为 ext4 文件系统。
        :param pulumi.Input[builtins.str] image_id: 节点对应的 ECS 实例使用的镜像 ID。
        :param pulumi.Input[builtins.str] initialize_script: 创建 ECS 节点并完成 Kubernetes 组件部署后执行的脚本。支持 Shell 格式，Base64 编码后长度不超过 1 KB。为空时，节点继承使用默认节点池配置的初始化脚本NodeConfig.InitializeScript。自定义填写脚本内容后，使用自定义的脚本，忽略默认节点池配置的初始化脚本。
        :param pulumi.Input[builtins.str] instance_id: 节点对应的云服务器实例 ID。
        :param pulumi.Input[builtins.bool] keep_instance_name: 是否保留原 ECS 实例名称，取值：false：（默认值）不保留原 ECS 实例名称，由容器服务自动为其命名。true：保留原 ECS 实例名称。
        :param pulumi.Input[Union['NodeKubernetesConfigArgs', 'NodeKubernetesConfigArgsDict']] kubernetes_config: 节点 Kubernetes 相关配置。为空时，节点继承使用默认节点池的 Kubernetes 配置KubernetesConfig.Labels/Taints/Cordon。自定义填写配置后，使用自定义配置内容，忽略默认节点池的 Kubernetes 配置。
        :param pulumi.Input[builtins.str] node_pool_id: 节点池 ID。不传入参数值：表示将已有 ECS 实例添加到默认节点池。传入参数值：表示将已有 ECS 实例添加到自定义节点池。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: NodeArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        对应 Kubernetes 中的 Node，是容器服务集群组成的基本元素。节点主要包括：Master 节点（控制节点）和 Worker 节点（计算节点/工作节点）。应用实际部署在 Worker 节点上，支持通过配置随机部署在 Worker 节点上或部署在指定的 Worker 节点上。容器服务中的 节点 一般指 Worker 节点。

        ## Example Usage

        ```python
        import pulumi
        import pulumi_bytepluscc as bytepluscc

        vke_node_demo = bytepluscc.vke.Node("VkeNodeDemo",
            additional_container_storage_enabled=False,
            cluster_id="cd5rdfs5ixxxxxotsc2g",
            container_storage_path="",
            instance_id="i-yeekjuixxxxx4je5vfr",
            keep_instance_name=True,
            node_pool_id="pd5s9srqxxxxxo88e621g")
        ```

        ## Import

        ```sh
        $ pulumi import bytepluscc:vke/node:Node example "cluster_id|node_pool_id|node_id"
        ```

        :param str resource_name: The name of the resource.
        :param NodeArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(NodeArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 additional_container_storage_enabled: Optional[pulumi.Input[builtins.bool]] = None,
                 cluster_id: Optional[pulumi.Input[builtins.str]] = None,
                 container_storage_path: Optional[pulumi.Input[builtins.str]] = None,
                 image_id: Optional[pulumi.Input[builtins.str]] = None,
                 initialize_script: Optional[pulumi.Input[builtins.str]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 keep_instance_name: Optional[pulumi.Input[builtins.bool]] = None,
                 kubernetes_config: Optional[pulumi.Input[Union['NodeKubernetesConfigArgs', 'NodeKubernetesConfigArgsDict']]] = None,
                 node_pool_id: Optional[pulumi.Input[builtins.str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = NodeArgs.__new__(NodeArgs)

            __props__.__dict__["additional_container_storage_enabled"] = additional_container_storage_enabled
            if cluster_id is None and not opts.urn:
                raise TypeError("Missing required property 'cluster_id'")
            __props__.__dict__["cluster_id"] = cluster_id
            __props__.__dict__["container_storage_path"] = container_storage_path
            __props__.__dict__["image_id"] = image_id
            __props__.__dict__["initialize_script"] = initialize_script
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["keep_instance_name"] = keep_instance_name
            __props__.__dict__["kubernetes_config"] = kubernetes_config
            if node_pool_id is None and not opts.urn:
                raise TypeError("Missing required property 'node_pool_id'")
            __props__.__dict__["node_pool_id"] = node_pool_id
            __props__.__dict__["created_time"] = None
            __props__.__dict__["is_virtual"] = None
            __props__.__dict__["name"] = None
            __props__.__dict__["node_id"] = None
            __props__.__dict__["roles"] = None
            __props__.__dict__["status"] = None
            __props__.__dict__["updated_time"] = None
            __props__.__dict__["zone_id"] = None
        super(Node, __self__).__init__(
            'bytepluscc:vke/node:Node',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            additional_container_storage_enabled: Optional[pulumi.Input[builtins.bool]] = None,
            cluster_id: Optional[pulumi.Input[builtins.str]] = None,
            container_storage_path: Optional[pulumi.Input[builtins.str]] = None,
            created_time: Optional[pulumi.Input[builtins.str]] = None,
            image_id: Optional[pulumi.Input[builtins.str]] = None,
            initialize_script: Optional[pulumi.Input[builtins.str]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            is_virtual: Optional[pulumi.Input[builtins.bool]] = None,
            keep_instance_name: Optional[pulumi.Input[builtins.bool]] = None,
            kubernetes_config: Optional[pulumi.Input[Union['NodeKubernetesConfigArgs', 'NodeKubernetesConfigArgsDict']]] = None,
            name: Optional[pulumi.Input[builtins.str]] = None,
            node_id: Optional[pulumi.Input[builtins.str]] = None,
            node_pool_id: Optional[pulumi.Input[builtins.str]] = None,
            roles: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            status: Optional[pulumi.Input[Union['NodeStatusArgs', 'NodeStatusArgsDict']]] = None,
            updated_time: Optional[pulumi.Input[builtins.str]] = None,
            zone_id: Optional[pulumi.Input[builtins.str]] = None) -> 'Node':
        """
        Get an existing Node resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] additional_container_storage_enabled: 选择配置节点的数据盘并格式化挂载作为容器镜像和日志的存储目录，取值：false：（默认值）关闭。默认节点池：表示不挂载数据盘。自定义节点池：使用节点池的数据盘配置进行挂载，被添加到节点池的 ECS 实例数据盘必须包含目标节点池指定了挂载的数据盘（含本地盘），且盘类型和大小完全一致。true: 开启。此时必须同时配置 ContainerStoragePath 参数。节点通过 ContainerStoragePath参数中的配置进行挂载，而忽略节点池的数据盘配置，对被添加到节点池的 ECS 实例数据盘无特殊要求。
        :param pulumi.Input[builtins.str] cluster_id: 集群的 ID。
        :param pulumi.Input[builtins.str] container_storage_path: 使用该数据盘设备挂载容器和镜像存储目录/var/lib/containerd。
               仅当AdditionalContainerStorageEnabled=true时有效，且不能为空。须满足以下条件，否则将初始化失败：仅支持已挂载数据盘的 ECS 实例。指定数据盘设备名时，请确保该数据盘设备存在，否则会初始化失败。指定数据盘分区或逻辑卷名时，请确保该分区或逻辑卷存在，且为 ext4 文件系统。
        :param pulumi.Input[builtins.str] created_time: 创建时间。
        :param pulumi.Input[builtins.str] image_id: 节点对应的 ECS 实例使用的镜像 ID。
        :param pulumi.Input[builtins.str] initialize_script: 创建 ECS 节点并完成 Kubernetes 组件部署后执行的脚本。支持 Shell 格式，Base64 编码后长度不超过 1 KB。为空时，节点继承使用默认节点池配置的初始化脚本NodeConfig.InitializeScript。自定义填写脚本内容后，使用自定义的脚本，忽略默认节点池配置的初始化脚本。
        :param pulumi.Input[builtins.str] instance_id: 节点对应的云服务器实例 ID。
        :param pulumi.Input[builtins.bool] is_virtual: 是否为虚拟节点，参数值说明：false：否 true：是。
        :param pulumi.Input[builtins.bool] keep_instance_name: 是否保留原 ECS 实例名称，取值：false：（默认值）不保留原 ECS 实例名称，由容器服务自动为其命名。true：保留原 ECS 实例名称。
        :param pulumi.Input[Union['NodeKubernetesConfigArgs', 'NodeKubernetesConfigArgsDict']] kubernetes_config: 节点 Kubernetes 相关配置。为空时，节点继承使用默认节点池的 Kubernetes 配置KubernetesConfig.Labels/Taints/Cordon。自定义填写配置后，使用自定义配置内容，忽略默认节点池的 Kubernetes 配置。
        :param pulumi.Input[builtins.str] name: 节点名称。
        :param pulumi.Input[builtins.str] node_id: 节点 ID。
        :param pulumi.Input[builtins.str] node_pool_id: 节点池 ID。不传入参数值：表示将已有 ECS 实例添加到默认节点池。传入参数值：表示将已有 ECS 实例添加到自定义节点池。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] roles: 节点角色，参数值说明：Worker：Worker节点。
        :param pulumi.Input[Union['NodeStatusArgs', 'NodeStatusArgsDict']] status: 节点状态。
        :param pulumi.Input[builtins.str] updated_time: 更新时间。
        :param pulumi.Input[builtins.str] zone_id: 可用区 ID。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _NodeState.__new__(_NodeState)

        __props__.__dict__["additional_container_storage_enabled"] = additional_container_storage_enabled
        __props__.__dict__["cluster_id"] = cluster_id
        __props__.__dict__["container_storage_path"] = container_storage_path
        __props__.__dict__["created_time"] = created_time
        __props__.__dict__["image_id"] = image_id
        __props__.__dict__["initialize_script"] = initialize_script
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["is_virtual"] = is_virtual
        __props__.__dict__["keep_instance_name"] = keep_instance_name
        __props__.__dict__["kubernetes_config"] = kubernetes_config
        __props__.__dict__["name"] = name
        __props__.__dict__["node_id"] = node_id
        __props__.__dict__["node_pool_id"] = node_pool_id
        __props__.__dict__["roles"] = roles
        __props__.__dict__["status"] = status
        __props__.__dict__["updated_time"] = updated_time
        __props__.__dict__["zone_id"] = zone_id
        return Node(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="additionalContainerStorageEnabled")
    def additional_container_storage_enabled(self) -> pulumi.Output[builtins.bool]:
        """
        选择配置节点的数据盘并格式化挂载作为容器镜像和日志的存储目录，取值：false：（默认值）关闭。默认节点池：表示不挂载数据盘。自定义节点池：使用节点池的数据盘配置进行挂载，被添加到节点池的 ECS 实例数据盘必须包含目标节点池指定了挂载的数据盘（含本地盘），且盘类型和大小完全一致。true: 开启。此时必须同时配置 ContainerStoragePath 参数。节点通过 ContainerStoragePath参数中的配置进行挂载，而忽略节点池的数据盘配置，对被添加到节点池的 ECS 实例数据盘无特殊要求。
        """
        return pulumi.get(self, "additional_container_storage_enabled")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> pulumi.Output[builtins.str]:
        """
        集群的 ID。
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="containerStoragePath")
    def container_storage_path(self) -> pulumi.Output[builtins.str]:
        """
        使用该数据盘设备挂载容器和镜像存储目录/var/lib/containerd。
        仅当AdditionalContainerStorageEnabled=true时有效，且不能为空。须满足以下条件，否则将初始化失败：仅支持已挂载数据盘的 ECS 实例。指定数据盘设备名时，请确保该数据盘设备存在，否则会初始化失败。指定数据盘分区或逻辑卷名时，请确保该分区或逻辑卷存在，且为 ext4 文件系统。
        """
        return pulumi.get(self, "container_storage_path")

    @property
    @pulumi.getter(name="createdTime")
    def created_time(self) -> pulumi.Output[builtins.str]:
        """
        创建时间。
        """
        return pulumi.get(self, "created_time")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> pulumi.Output[builtins.str]:
        """
        节点对应的 ECS 实例使用的镜像 ID。
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="initializeScript")
    def initialize_script(self) -> pulumi.Output[builtins.str]:
        """
        创建 ECS 节点并完成 Kubernetes 组件部署后执行的脚本。支持 Shell 格式，Base64 编码后长度不超过 1 KB。为空时，节点继承使用默认节点池配置的初始化脚本NodeConfig.InitializeScript。自定义填写脚本内容后，使用自定义的脚本，忽略默认节点池配置的初始化脚本。
        """
        return pulumi.get(self, "initialize_script")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        节点对应的云服务器实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="isVirtual")
    def is_virtual(self) -> pulumi.Output[builtins.bool]:
        """
        是否为虚拟节点，参数值说明：false：否 true：是。
        """
        return pulumi.get(self, "is_virtual")

    @property
    @pulumi.getter(name="keepInstanceName")
    def keep_instance_name(self) -> pulumi.Output[builtins.bool]:
        """
        是否保留原 ECS 实例名称，取值：false：（默认值）不保留原 ECS 实例名称，由容器服务自动为其命名。true：保留原 ECS 实例名称。
        """
        return pulumi.get(self, "keep_instance_name")

    @property
    @pulumi.getter(name="kubernetesConfig")
    def kubernetes_config(self) -> pulumi.Output['outputs.NodeKubernetesConfig']:
        """
        节点 Kubernetes 相关配置。为空时，节点继承使用默认节点池的 Kubernetes 配置KubernetesConfig.Labels/Taints/Cordon。自定义填写配置后，使用自定义配置内容，忽略默认节点池的 Kubernetes 配置。
        """
        return pulumi.get(self, "kubernetes_config")

    @property
    @pulumi.getter
    def name(self) -> pulumi.Output[builtins.str]:
        """
        节点名称。
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="nodeId")
    def node_id(self) -> pulumi.Output[builtins.str]:
        """
        节点 ID。
        """
        return pulumi.get(self, "node_id")

    @property
    @pulumi.getter(name="nodePoolId")
    def node_pool_id(self) -> pulumi.Output[builtins.str]:
        """
        节点池 ID。不传入参数值：表示将已有 ECS 实例添加到默认节点池。传入参数值：表示将已有 ECS 实例添加到自定义节点池。
        """
        return pulumi.get(self, "node_pool_id")

    @property
    @pulumi.getter
    def roles(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        节点角色，参数值说明：Worker：Worker节点。
        """
        return pulumi.get(self, "roles")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output['outputs.NodeStatus']:
        """
        节点状态。
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="updatedTime")
    def updated_time(self) -> pulumi.Output[builtins.str]:
        """
        更新时间。
        """
        return pulumi.get(self, "updated_time")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> pulumi.Output[builtins.str]:
        """
        可用区 ID。
        """
        return pulumi.get(self, "zone_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['EndpointArgs', 'Endpoint']

@pulumi.input_type
class EndpointArgs:
    def __init__(__self__, *,
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]] = None,
                 auto_add_new_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connect_all_slave_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_mode: Optional[pulumi.Input[builtins.str]] = None,
                 connection_pool_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_connection_persistent: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoint_name: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
                 idle_connection_reclaim: Optional[pulumi.Input[builtins.bool]] = None,
                 implicit_trans_split: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 master_node_routing: Optional[pulumi.Input[builtins.bool]] = None,
                 master_protector_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 multi_statements_mode: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[builtins.str]] = None,
                 overload_protection: Optional[pulumi.Input[builtins.bool]] = None,
                 read_only_node_distribution_type: Optional[pulumi.Input[builtins.str]] = None,
                 read_only_node_max_delay_time: Optional[pulumi.Input[builtins.int]] = None,
                 read_only_node_weights: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]] = None,
                 read_write_mode: Optional[pulumi.Input[builtins.str]] = None,
                 read_write_spliting: Optional[pulumi.Input[builtins.bool]] = None):
        """
        The set of arguments for constructing a Endpoint resource.
        :param pulumi.Input[builtins.bool] auto_add_new_nodes: 当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        :param pulumi.Input[builtins.bool] connect_all_slave_nodes: 是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        :param pulumi.Input[builtins.str] connection_mode: 连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        :param pulumi.Input[builtins.str] connection_pool_type: 代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        :param pulumi.Input[builtins.str] description: 备注。
        :param pulumi.Input[builtins.bool] enable_connection_persistent: 是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        :param pulumi.Input[builtins.str] endpoint_name: 实例连接终端名称。
        :param pulumi.Input[builtins.str] endpoint_type: 终端类型。取值为 Custom，自定义终端。
        :param pulumi.Input[builtins.bool] idle_connection_reclaim: 空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.bool] implicit_trans_split: 是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] master_node_routing: 是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.int] master_protector_timeout: 过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] multi_statements_mode: 代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        :param pulumi.Input[builtins.str] nodes: 连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        :param pulumi.Input[builtins.bool] overload_protection: 是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] read_only_node_distribution_type: 读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        :param pulumi.Input[builtins.int] read_only_node_max_delay_time: 只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        :param pulumi.Input[builtins.str] read_write_mode: 读写模式：ReadWrite：读写。ReadOnly：只读。
        :param pulumi.Input[builtins.bool] read_write_spliting: 是否开启读写分离。取值：true：是。默认值。false：否。
        """
        if addresses is not None:
            pulumi.set(__self__, "addresses", addresses)
        if auto_add_new_nodes is not None:
            pulumi.set(__self__, "auto_add_new_nodes", auto_add_new_nodes)
        if connect_all_slave_nodes is not None:
            pulumi.set(__self__, "connect_all_slave_nodes", connect_all_slave_nodes)
        if connection_mode is not None:
            pulumi.set(__self__, "connection_mode", connection_mode)
        if connection_pool_type is not None:
            pulumi.set(__self__, "connection_pool_type", connection_pool_type)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_connection_persistent is not None:
            pulumi.set(__self__, "enable_connection_persistent", enable_connection_persistent)
        if endpoint_name is not None:
            pulumi.set(__self__, "endpoint_name", endpoint_name)
        if endpoint_type is not None:
            pulumi.set(__self__, "endpoint_type", endpoint_type)
        if idle_connection_reclaim is not None:
            pulumi.set(__self__, "idle_connection_reclaim", idle_connection_reclaim)
        if implicit_trans_split is not None:
            pulumi.set(__self__, "implicit_trans_split", implicit_trans_split)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if master_node_routing is not None:
            pulumi.set(__self__, "master_node_routing", master_node_routing)
        if master_protector_timeout is not None:
            pulumi.set(__self__, "master_protector_timeout", master_protector_timeout)
        if multi_statements_mode is not None:
            pulumi.set(__self__, "multi_statements_mode", multi_statements_mode)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if overload_protection is not None:
            pulumi.set(__self__, "overload_protection", overload_protection)
        if read_only_node_distribution_type is not None:
            pulumi.set(__self__, "read_only_node_distribution_type", read_only_node_distribution_type)
        if read_only_node_max_delay_time is not None:
            pulumi.set(__self__, "read_only_node_max_delay_time", read_only_node_max_delay_time)
        if read_only_node_weights is not None:
            pulumi.set(__self__, "read_only_node_weights", read_only_node_weights)
        if read_write_mode is not None:
            pulumi.set(__self__, "read_write_mode", read_write_mode)
        if read_write_spliting is not None:
            pulumi.set(__self__, "read_write_spliting", read_write_spliting)

    @property
    @pulumi.getter
    def addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]]:
        return pulumi.get(self, "addresses")

    @addresses.setter
    def addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]]):
        pulumi.set(self, "addresses", value)

    @property
    @pulumi.getter(name="autoAddNewNodes")
    def auto_add_new_nodes(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        """
        return pulumi.get(self, "auto_add_new_nodes")

    @auto_add_new_nodes.setter
    def auto_add_new_nodes(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_add_new_nodes", value)

    @property
    @pulumi.getter(name="connectAllSlaveNodes")
    def connect_all_slave_nodes(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        """
        return pulumi.get(self, "connect_all_slave_nodes")

    @connect_all_slave_nodes.setter
    def connect_all_slave_nodes(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "connect_all_slave_nodes", value)

    @property
    @pulumi.getter(name="connectionMode")
    def connection_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        """
        return pulumi.get(self, "connection_mode")

    @connection_mode.setter
    def connection_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_mode", value)

    @property
    @pulumi.getter(name="connectionPoolType")
    def connection_pool_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        """
        return pulumi.get(self, "connection_pool_type")

    @connection_pool_type.setter
    def connection_pool_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_pool_type", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableConnectionPersistent")
    def enable_connection_persistent(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        """
        return pulumi.get(self, "enable_connection_persistent")

    @enable_connection_persistent.setter
    def enable_connection_persistent(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_connection_persistent", value)

    @property
    @pulumi.getter(name="endpointName")
    def endpoint_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例连接终端名称。
        """
        return pulumi.get(self, "endpoint_name")

    @endpoint_name.setter
    def endpoint_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_name", value)

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端类型。取值为 Custom，自定义终端。
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_type", value)

    @property
    @pulumi.getter(name="idleConnectionReclaim")
    def idle_connection_reclaim(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "idle_connection_reclaim")

    @idle_connection_reclaim.setter
    def idle_connection_reclaim(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "idle_connection_reclaim", value)

    @property
    @pulumi.getter(name="implicitTransSplit")
    def implicit_trans_split(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "implicit_trans_split")

    @implicit_trans_split.setter
    def implicit_trans_split(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "implicit_trans_split", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="masterNodeRouting")
    def master_node_routing(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_node_routing")

    @master_node_routing.setter
    def master_node_routing(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "master_node_routing", value)

    @property
    @pulumi.getter(name="masterProtectorTimeout")
    def master_protector_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_protector_timeout")

    @master_protector_timeout.setter
    def master_protector_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "master_protector_timeout", value)

    @property
    @pulumi.getter(name="multiStatementsMode")
    def multi_statements_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        """
        return pulumi.get(self, "multi_statements_mode")

    @multi_statements_mode.setter
    def multi_statements_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "multi_statements_mode", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter(name="overloadProtection")
    def overload_protection(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "overload_protection")

    @overload_protection.setter
    def overload_protection(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "overload_protection", value)

    @property
    @pulumi.getter(name="readOnlyNodeDistributionType")
    def read_only_node_distribution_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        """
        return pulumi.get(self, "read_only_node_distribution_type")

    @read_only_node_distribution_type.setter
    def read_only_node_distribution_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "read_only_node_distribution_type", value)

    @property
    @pulumi.getter(name="readOnlyNodeMaxDelayTime")
    def read_only_node_max_delay_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        """
        return pulumi.get(self, "read_only_node_max_delay_time")

    @read_only_node_max_delay_time.setter
    def read_only_node_max_delay_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "read_only_node_max_delay_time", value)

    @property
    @pulumi.getter(name="readOnlyNodeWeights")
    def read_only_node_weights(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]]:
        return pulumi.get(self, "read_only_node_weights")

    @read_only_node_weights.setter
    def read_only_node_weights(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]]):
        pulumi.set(self, "read_only_node_weights", value)

    @property
    @pulumi.getter(name="readWriteMode")
    def read_write_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        读写模式：ReadWrite：读写。ReadOnly：只读。
        """
        return pulumi.get(self, "read_write_mode")

    @read_write_mode.setter
    def read_write_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "read_write_mode", value)

    @property
    @pulumi.getter(name="readWriteSpliting")
    def read_write_spliting(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启读写分离。取值：true：是。默认值。false：否。
        """
        return pulumi.get(self, "read_write_spliting")

    @read_write_spliting.setter
    def read_write_spliting(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "read_write_spliting", value)


@pulumi.input_type
class _EndpointState:
    def __init__(__self__, *,
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]] = None,
                 auto_add_new_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connect_all_slave_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_info_tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
                 connection_mode: Optional[pulumi.Input[builtins.str]] = None,
                 connection_pool_type: Optional[pulumi.Input[builtins.str]] = None,
                 custom_route_strategy: Optional[pulumi.Input['EndpointCustomRouteStrategyArgs']] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_connection_persistent: Optional[pulumi.Input[builtins.bool]] = None,
                 enable_read_only: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_id: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_name: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
                 idle_connection_reclaim: Optional[pulumi.Input[builtins.bool]] = None,
                 implicit_trans_split: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 master_node_routing: Optional[pulumi.Input[builtins.bool]] = None,
                 master_protector_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 multi_statements_mode: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[builtins.str]] = None,
                 overload_protection: Optional[pulumi.Input[builtins.bool]] = None,
                 read_only_node_distribution_type: Optional[pulumi.Input[builtins.str]] = None,
                 read_only_node_max_delay_time: Optional[pulumi.Input[builtins.int]] = None,
                 read_only_node_weights: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]] = None,
                 read_write_mode: Optional[pulumi.Input[builtins.str]] = None,
                 read_write_spliting: Optional[pulumi.Input[builtins.bool]] = None):
        """
        Input properties used for looking up and filtering Endpoint resources.
        :param pulumi.Input[builtins.bool] auto_add_new_nodes: 当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        :param pulumi.Input[builtins.bool] connect_all_slave_nodes: 是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] connection_info_tags: 连接终端标签。
        :param pulumi.Input[builtins.str] connection_mode: 连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        :param pulumi.Input[builtins.str] connection_pool_type: 代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        :param pulumi.Input['EndpointCustomRouteStrategyArgs'] custom_route_strategy: 连接终端的 SQL 转发规则。
        :param pulumi.Input[builtins.str] description: 备注。
        :param pulumi.Input[builtins.bool] enable_connection_persistent: 是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        :param pulumi.Input[builtins.str] enable_read_only: 是否已开启全局只读，取值：Enable：开启。Disable：未开启。
        :param pulumi.Input[builtins.str] endpoint_id: 实例连接终端 ID。
        :param pulumi.Input[builtins.str] endpoint_name: 实例连接终端名称。
        :param pulumi.Input[builtins.str] endpoint_type: 终端类型。取值为 Custom，自定义终端。
        :param pulumi.Input[builtins.bool] idle_connection_reclaim: 空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.bool] implicit_trans_split: 是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] master_node_routing: 是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.int] master_protector_timeout: 过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] multi_statements_mode: 代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        :param pulumi.Input[builtins.str] nodes: 连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        :param pulumi.Input[builtins.bool] overload_protection: 是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] read_only_node_distribution_type: 读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        :param pulumi.Input[builtins.int] read_only_node_max_delay_time: 只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        :param pulumi.Input[builtins.str] read_write_mode: 读写模式：ReadWrite：读写。ReadOnly：只读。
        :param pulumi.Input[builtins.bool] read_write_spliting: 是否开启读写分离。取值：true：是。默认值。false：否。
        """
        if addresses is not None:
            pulumi.set(__self__, "addresses", addresses)
        if auto_add_new_nodes is not None:
            pulumi.set(__self__, "auto_add_new_nodes", auto_add_new_nodes)
        if connect_all_slave_nodes is not None:
            pulumi.set(__self__, "connect_all_slave_nodes", connect_all_slave_nodes)
        if connection_info_tags is not None:
            pulumi.set(__self__, "connection_info_tags", connection_info_tags)
        if connection_mode is not None:
            pulumi.set(__self__, "connection_mode", connection_mode)
        if connection_pool_type is not None:
            pulumi.set(__self__, "connection_pool_type", connection_pool_type)
        if custom_route_strategy is not None:
            pulumi.set(__self__, "custom_route_strategy", custom_route_strategy)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_connection_persistent is not None:
            pulumi.set(__self__, "enable_connection_persistent", enable_connection_persistent)
        if enable_read_only is not None:
            pulumi.set(__self__, "enable_read_only", enable_read_only)
        if endpoint_id is not None:
            pulumi.set(__self__, "endpoint_id", endpoint_id)
        if endpoint_name is not None:
            pulumi.set(__self__, "endpoint_name", endpoint_name)
        if endpoint_type is not None:
            pulumi.set(__self__, "endpoint_type", endpoint_type)
        if idle_connection_reclaim is not None:
            pulumi.set(__self__, "idle_connection_reclaim", idle_connection_reclaim)
        if implicit_trans_split is not None:
            pulumi.set(__self__, "implicit_trans_split", implicit_trans_split)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if master_node_routing is not None:
            pulumi.set(__self__, "master_node_routing", master_node_routing)
        if master_protector_timeout is not None:
            pulumi.set(__self__, "master_protector_timeout", master_protector_timeout)
        if multi_statements_mode is not None:
            pulumi.set(__self__, "multi_statements_mode", multi_statements_mode)
        if nodes is not None:
            pulumi.set(__self__, "nodes", nodes)
        if overload_protection is not None:
            pulumi.set(__self__, "overload_protection", overload_protection)
        if read_only_node_distribution_type is not None:
            pulumi.set(__self__, "read_only_node_distribution_type", read_only_node_distribution_type)
        if read_only_node_max_delay_time is not None:
            pulumi.set(__self__, "read_only_node_max_delay_time", read_only_node_max_delay_time)
        if read_only_node_weights is not None:
            pulumi.set(__self__, "read_only_node_weights", read_only_node_weights)
        if read_write_mode is not None:
            pulumi.set(__self__, "read_write_mode", read_write_mode)
        if read_write_spliting is not None:
            pulumi.set(__self__, "read_write_spliting", read_write_spliting)

    @property
    @pulumi.getter
    def addresses(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]]:
        return pulumi.get(self, "addresses")

    @addresses.setter
    def addresses(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointAddressArgs']]]]):
        pulumi.set(self, "addresses", value)

    @property
    @pulumi.getter(name="autoAddNewNodes")
    def auto_add_new_nodes(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        """
        return pulumi.get(self, "auto_add_new_nodes")

    @auto_add_new_nodes.setter
    def auto_add_new_nodes(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "auto_add_new_nodes", value)

    @property
    @pulumi.getter(name="connectAllSlaveNodes")
    def connect_all_slave_nodes(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        """
        return pulumi.get(self, "connect_all_slave_nodes")

    @connect_all_slave_nodes.setter
    def connect_all_slave_nodes(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "connect_all_slave_nodes", value)

    @property
    @pulumi.getter(name="connectionInfoTags")
    def connection_info_tags(self) -> Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]:
        """
        连接终端标签。
        """
        return pulumi.get(self, "connection_info_tags")

    @connection_info_tags.setter
    def connection_info_tags(self, value: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]]):
        pulumi.set(self, "connection_info_tags", value)

    @property
    @pulumi.getter(name="connectionMode")
    def connection_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        """
        return pulumi.get(self, "connection_mode")

    @connection_mode.setter
    def connection_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_mode", value)

    @property
    @pulumi.getter(name="connectionPoolType")
    def connection_pool_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        """
        return pulumi.get(self, "connection_pool_type")

    @connection_pool_type.setter
    def connection_pool_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "connection_pool_type", value)

    @property
    @pulumi.getter(name="customRouteStrategy")
    def custom_route_strategy(self) -> Optional[pulumi.Input['EndpointCustomRouteStrategyArgs']]:
        """
        连接终端的 SQL 转发规则。
        """
        return pulumi.get(self, "custom_route_strategy")

    @custom_route_strategy.setter
    def custom_route_strategy(self, value: Optional[pulumi.Input['EndpointCustomRouteStrategyArgs']]):
        pulumi.set(self, "custom_route_strategy", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        备注。
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableConnectionPersistent")
    def enable_connection_persistent(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        """
        return pulumi.get(self, "enable_connection_persistent")

    @enable_connection_persistent.setter
    def enable_connection_persistent(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "enable_connection_persistent", value)

    @property
    @pulumi.getter(name="enableReadOnly")
    def enable_read_only(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        是否已开启全局只读，取值：Enable：开启。Disable：未开启。
        """
        return pulumi.get(self, "enable_read_only")

    @enable_read_only.setter
    def enable_read_only(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "enable_read_only", value)

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例连接终端 ID。
        """
        return pulumi.get(self, "endpoint_id")

    @endpoint_id.setter
    def endpoint_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_id", value)

    @property
    @pulumi.getter(name="endpointName")
    def endpoint_name(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例连接终端名称。
        """
        return pulumi.get(self, "endpoint_name")

    @endpoint_name.setter
    def endpoint_name(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_name", value)

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        终端类型。取值为 Custom，自定义终端。
        """
        return pulumi.get(self, "endpoint_type")

    @endpoint_type.setter
    def endpoint_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "endpoint_type", value)

    @property
    @pulumi.getter(name="idleConnectionReclaim")
    def idle_connection_reclaim(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "idle_connection_reclaim")

    @idle_connection_reclaim.setter
    def idle_connection_reclaim(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "idle_connection_reclaim", value)

    @property
    @pulumi.getter(name="implicitTransSplit")
    def implicit_trans_split(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "implicit_trans_split")

    @implicit_trans_split.setter
    def implicit_trans_split(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "implicit_trans_split", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="masterNodeRouting")
    def master_node_routing(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_node_routing")

    @master_node_routing.setter
    def master_node_routing(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "master_node_routing", value)

    @property
    @pulumi.getter(name="masterProtectorTimeout")
    def master_protector_timeout(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_protector_timeout")

    @master_protector_timeout.setter
    def master_protector_timeout(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "master_protector_timeout", value)

    @property
    @pulumi.getter(name="multiStatementsMode")
    def multi_statements_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        """
        return pulumi.get(self, "multi_statements_mode")

    @multi_statements_mode.setter
    def multi_statements_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "multi_statements_mode", value)

    @property
    @pulumi.getter
    def nodes(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        """
        return pulumi.get(self, "nodes")

    @nodes.setter
    def nodes(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "nodes", value)

    @property
    @pulumi.getter(name="overloadProtection")
    def overload_protection(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "overload_protection")

    @overload_protection.setter
    def overload_protection(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "overload_protection", value)

    @property
    @pulumi.getter(name="readOnlyNodeDistributionType")
    def read_only_node_distribution_type(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        """
        return pulumi.get(self, "read_only_node_distribution_type")

    @read_only_node_distribution_type.setter
    def read_only_node_distribution_type(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "read_only_node_distribution_type", value)

    @property
    @pulumi.getter(name="readOnlyNodeMaxDelayTime")
    def read_only_node_max_delay_time(self) -> Optional[pulumi.Input[builtins.int]]:
        """
        只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        """
        return pulumi.get(self, "read_only_node_max_delay_time")

    @read_only_node_max_delay_time.setter
    def read_only_node_max_delay_time(self, value: Optional[pulumi.Input[builtins.int]]):
        pulumi.set(self, "read_only_node_max_delay_time", value)

    @property
    @pulumi.getter(name="readOnlyNodeWeights")
    def read_only_node_weights(self) -> Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]]:
        return pulumi.get(self, "read_only_node_weights")

    @read_only_node_weights.setter
    def read_only_node_weights(self, value: Optional[pulumi.Input[Sequence[pulumi.Input['EndpointReadOnlyNodeWeightArgs']]]]):
        pulumi.set(self, "read_only_node_weights", value)

    @property
    @pulumi.getter(name="readWriteMode")
    def read_write_mode(self) -> Optional[pulumi.Input[builtins.str]]:
        """
        读写模式：ReadWrite：读写。ReadOnly：只读。
        """
        return pulumi.get(self, "read_write_mode")

    @read_write_mode.setter
    def read_write_mode(self, value: Optional[pulumi.Input[builtins.str]]):
        pulumi.set(self, "read_write_mode", value)

    @property
    @pulumi.getter(name="readWriteSpliting")
    def read_write_spliting(self) -> Optional[pulumi.Input[builtins.bool]]:
        """
        是否开启读写分离。取值：true：是。默认值。false：否。
        """
        return pulumi.get(self, "read_write_spliting")

    @read_write_spliting.setter
    def read_write_spliting(self, value: Optional[pulumi.Input[builtins.bool]]):
        pulumi.set(self, "read_write_spliting", value)


@pulumi.type_token("bytepluscc:rdsmysql/endpoint:Endpoint")
class Endpoint(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointAddressArgs', 'EndpointAddressArgsDict']]]]] = None,
                 auto_add_new_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connect_all_slave_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_mode: Optional[pulumi.Input[builtins.str]] = None,
                 connection_pool_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_connection_persistent: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoint_name: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
                 idle_connection_reclaim: Optional[pulumi.Input[builtins.bool]] = None,
                 implicit_trans_split: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 master_node_routing: Optional[pulumi.Input[builtins.bool]] = None,
                 master_protector_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 multi_statements_mode: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[builtins.str]] = None,
                 overload_protection: Optional[pulumi.Input[builtins.bool]] = None,
                 read_only_node_distribution_type: Optional[pulumi.Input[builtins.str]] = None,
                 read_only_node_max_delay_time: Optional[pulumi.Input[builtins.int]] = None,
                 read_only_node_weights: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointReadOnlyNodeWeightArgs', 'EndpointReadOnlyNodeWeightArgsDict']]]]] = None,
                 read_write_mode: Optional[pulumi.Input[builtins.str]] = None,
                 read_write_spliting: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        """
        连接终端是云数据库 MySQL 版提供的位于数据库和应用程序之间的网络代理服务。根据连接终端的功能差异，连接终端可以分为代理终端和直连终端两种类型。通过代理终端的连接将经过代理，可使用代理相关的特性和功能，如读写分离、负载均衡、空闲连接回收和 Multi-Statements 等；通过直连终端的连接将直连到对应节点，不能使用代理相关特性。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/endpoint:Endpoint example "instance_id|endpoint_id"
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_add_new_nodes: 当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        :param pulumi.Input[builtins.bool] connect_all_slave_nodes: 是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        :param pulumi.Input[builtins.str] connection_mode: 连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        :param pulumi.Input[builtins.str] connection_pool_type: 代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        :param pulumi.Input[builtins.str] description: 备注。
        :param pulumi.Input[builtins.bool] enable_connection_persistent: 是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        :param pulumi.Input[builtins.str] endpoint_name: 实例连接终端名称。
        :param pulumi.Input[builtins.str] endpoint_type: 终端类型。取值为 Custom，自定义终端。
        :param pulumi.Input[builtins.bool] idle_connection_reclaim: 空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.bool] implicit_trans_split: 是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] master_node_routing: 是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.int] master_protector_timeout: 过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] multi_statements_mode: 代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        :param pulumi.Input[builtins.str] nodes: 连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        :param pulumi.Input[builtins.bool] overload_protection: 是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] read_only_node_distribution_type: 读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        :param pulumi.Input[builtins.int] read_only_node_max_delay_time: 只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        :param pulumi.Input[builtins.str] read_write_mode: 读写模式：ReadWrite：读写。ReadOnly：只读。
        :param pulumi.Input[builtins.bool] read_write_spliting: 是否开启读写分离。取值：true：是。默认值。false：否。
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: Optional[EndpointArgs] = None,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        连接终端是云数据库 MySQL 版提供的位于数据库和应用程序之间的网络代理服务。根据连接终端的功能差异，连接终端可以分为代理终端和直连终端两种类型。通过代理终端的连接将经过代理，可使用代理相关的特性和功能，如读写分离、负载均衡、空闲连接回收和 Multi-Statements 等；通过直连终端的连接将直连到对应节点，不能使用代理相关特性。

        ## Import

        ```sh
        $ pulumi import bytepluscc:rdsmysql/endpoint:Endpoint example "instance_id|endpoint_id"
        ```

        :param str resource_name: The name of the resource.
        :param EndpointArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EndpointArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointAddressArgs', 'EndpointAddressArgsDict']]]]] = None,
                 auto_add_new_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connect_all_slave_nodes: Optional[pulumi.Input[builtins.bool]] = None,
                 connection_mode: Optional[pulumi.Input[builtins.str]] = None,
                 connection_pool_type: Optional[pulumi.Input[builtins.str]] = None,
                 description: Optional[pulumi.Input[builtins.str]] = None,
                 enable_connection_persistent: Optional[pulumi.Input[builtins.bool]] = None,
                 endpoint_name: Optional[pulumi.Input[builtins.str]] = None,
                 endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
                 idle_connection_reclaim: Optional[pulumi.Input[builtins.bool]] = None,
                 implicit_trans_split: Optional[pulumi.Input[builtins.bool]] = None,
                 instance_id: Optional[pulumi.Input[builtins.str]] = None,
                 master_node_routing: Optional[pulumi.Input[builtins.bool]] = None,
                 master_protector_timeout: Optional[pulumi.Input[builtins.int]] = None,
                 multi_statements_mode: Optional[pulumi.Input[builtins.str]] = None,
                 nodes: Optional[pulumi.Input[builtins.str]] = None,
                 overload_protection: Optional[pulumi.Input[builtins.bool]] = None,
                 read_only_node_distribution_type: Optional[pulumi.Input[builtins.str]] = None,
                 read_only_node_max_delay_time: Optional[pulumi.Input[builtins.int]] = None,
                 read_only_node_weights: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointReadOnlyNodeWeightArgs', 'EndpointReadOnlyNodeWeightArgsDict']]]]] = None,
                 read_write_mode: Optional[pulumi.Input[builtins.str]] = None,
                 read_write_spliting: Optional[pulumi.Input[builtins.bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EndpointArgs.__new__(EndpointArgs)

            __props__.__dict__["addresses"] = addresses
            __props__.__dict__["auto_add_new_nodes"] = auto_add_new_nodes
            __props__.__dict__["connect_all_slave_nodes"] = connect_all_slave_nodes
            __props__.__dict__["connection_mode"] = connection_mode
            __props__.__dict__["connection_pool_type"] = connection_pool_type
            __props__.__dict__["description"] = description
            __props__.__dict__["enable_connection_persistent"] = enable_connection_persistent
            __props__.__dict__["endpoint_name"] = endpoint_name
            __props__.__dict__["endpoint_type"] = endpoint_type
            __props__.__dict__["idle_connection_reclaim"] = idle_connection_reclaim
            __props__.__dict__["implicit_trans_split"] = implicit_trans_split
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["master_node_routing"] = master_node_routing
            __props__.__dict__["master_protector_timeout"] = master_protector_timeout
            __props__.__dict__["multi_statements_mode"] = multi_statements_mode
            __props__.__dict__["nodes"] = nodes
            __props__.__dict__["overload_protection"] = overload_protection
            __props__.__dict__["read_only_node_distribution_type"] = read_only_node_distribution_type
            __props__.__dict__["read_only_node_max_delay_time"] = read_only_node_max_delay_time
            __props__.__dict__["read_only_node_weights"] = read_only_node_weights
            __props__.__dict__["read_write_mode"] = read_write_mode
            __props__.__dict__["read_write_spliting"] = read_write_spliting
            __props__.__dict__["connection_info_tags"] = None
            __props__.__dict__["custom_route_strategy"] = None
            __props__.__dict__["enable_read_only"] = None
            __props__.__dict__["endpoint_id"] = None
        super(Endpoint, __self__).__init__(
            'bytepluscc:rdsmysql/endpoint:Endpoint',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            addresses: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointAddressArgs', 'EndpointAddressArgsDict']]]]] = None,
            auto_add_new_nodes: Optional[pulumi.Input[builtins.bool]] = None,
            connect_all_slave_nodes: Optional[pulumi.Input[builtins.bool]] = None,
            connection_info_tags: Optional[pulumi.Input[Sequence[pulumi.Input[builtins.str]]]] = None,
            connection_mode: Optional[pulumi.Input[builtins.str]] = None,
            connection_pool_type: Optional[pulumi.Input[builtins.str]] = None,
            custom_route_strategy: Optional[pulumi.Input[Union['EndpointCustomRouteStrategyArgs', 'EndpointCustomRouteStrategyArgsDict']]] = None,
            description: Optional[pulumi.Input[builtins.str]] = None,
            enable_connection_persistent: Optional[pulumi.Input[builtins.bool]] = None,
            enable_read_only: Optional[pulumi.Input[builtins.str]] = None,
            endpoint_id: Optional[pulumi.Input[builtins.str]] = None,
            endpoint_name: Optional[pulumi.Input[builtins.str]] = None,
            endpoint_type: Optional[pulumi.Input[builtins.str]] = None,
            idle_connection_reclaim: Optional[pulumi.Input[builtins.bool]] = None,
            implicit_trans_split: Optional[pulumi.Input[builtins.bool]] = None,
            instance_id: Optional[pulumi.Input[builtins.str]] = None,
            master_node_routing: Optional[pulumi.Input[builtins.bool]] = None,
            master_protector_timeout: Optional[pulumi.Input[builtins.int]] = None,
            multi_statements_mode: Optional[pulumi.Input[builtins.str]] = None,
            nodes: Optional[pulumi.Input[builtins.str]] = None,
            overload_protection: Optional[pulumi.Input[builtins.bool]] = None,
            read_only_node_distribution_type: Optional[pulumi.Input[builtins.str]] = None,
            read_only_node_max_delay_time: Optional[pulumi.Input[builtins.int]] = None,
            read_only_node_weights: Optional[pulumi.Input[Sequence[pulumi.Input[Union['EndpointReadOnlyNodeWeightArgs', 'EndpointReadOnlyNodeWeightArgsDict']]]]] = None,
            read_write_mode: Optional[pulumi.Input[builtins.str]] = None,
            read_write_spliting: Optional[pulumi.Input[builtins.bool]] = None) -> 'Endpoint':
        """
        Get an existing Endpoint resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[builtins.bool] auto_add_new_nodes: 当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        :param pulumi.Input[builtins.bool] connect_all_slave_nodes: 是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        :param pulumi.Input[Sequence[pulumi.Input[builtins.str]]] connection_info_tags: 连接终端标签。
        :param pulumi.Input[builtins.str] connection_mode: 连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        :param pulumi.Input[builtins.str] connection_pool_type: 代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        :param pulumi.Input[Union['EndpointCustomRouteStrategyArgs', 'EndpointCustomRouteStrategyArgsDict']] custom_route_strategy: 连接终端的 SQL 转发规则。
        :param pulumi.Input[builtins.str] description: 备注。
        :param pulumi.Input[builtins.bool] enable_connection_persistent: 是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        :param pulumi.Input[builtins.str] enable_read_only: 是否已开启全局只读，取值：Enable：开启。Disable：未开启。
        :param pulumi.Input[builtins.str] endpoint_id: 实例连接终端 ID。
        :param pulumi.Input[builtins.str] endpoint_name: 实例连接终端名称。
        :param pulumi.Input[builtins.str] endpoint_type: 终端类型。取值为 Custom，自定义终端。
        :param pulumi.Input[builtins.bool] idle_connection_reclaim: 空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.bool] implicit_trans_split: 是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] instance_id: 实例 ID。
        :param pulumi.Input[builtins.bool] master_node_routing: 是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.int] master_protector_timeout: 过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] multi_statements_mode: 代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        :param pulumi.Input[builtins.str] nodes: 连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        :param pulumi.Input[builtins.bool] overload_protection: 是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        :param pulumi.Input[builtins.str] read_only_node_distribution_type: 读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        :param pulumi.Input[builtins.int] read_only_node_max_delay_time: 只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        :param pulumi.Input[builtins.str] read_write_mode: 读写模式：ReadWrite：读写。ReadOnly：只读。
        :param pulumi.Input[builtins.bool] read_write_spliting: 是否开启读写分离。取值：true：是。默认值。false：否。
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EndpointState.__new__(_EndpointState)

        __props__.__dict__["addresses"] = addresses
        __props__.__dict__["auto_add_new_nodes"] = auto_add_new_nodes
        __props__.__dict__["connect_all_slave_nodes"] = connect_all_slave_nodes
        __props__.__dict__["connection_info_tags"] = connection_info_tags
        __props__.__dict__["connection_mode"] = connection_mode
        __props__.__dict__["connection_pool_type"] = connection_pool_type
        __props__.__dict__["custom_route_strategy"] = custom_route_strategy
        __props__.__dict__["description"] = description
        __props__.__dict__["enable_connection_persistent"] = enable_connection_persistent
        __props__.__dict__["enable_read_only"] = enable_read_only
        __props__.__dict__["endpoint_id"] = endpoint_id
        __props__.__dict__["endpoint_name"] = endpoint_name
        __props__.__dict__["endpoint_type"] = endpoint_type
        __props__.__dict__["idle_connection_reclaim"] = idle_connection_reclaim
        __props__.__dict__["implicit_trans_split"] = implicit_trans_split
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["master_node_routing"] = master_node_routing
        __props__.__dict__["master_protector_timeout"] = master_protector_timeout
        __props__.__dict__["multi_statements_mode"] = multi_statements_mode
        __props__.__dict__["nodes"] = nodes
        __props__.__dict__["overload_protection"] = overload_protection
        __props__.__dict__["read_only_node_distribution_type"] = read_only_node_distribution_type
        __props__.__dict__["read_only_node_max_delay_time"] = read_only_node_max_delay_time
        __props__.__dict__["read_only_node_weights"] = read_only_node_weights
        __props__.__dict__["read_write_mode"] = read_write_mode
        __props__.__dict__["read_write_spliting"] = read_write_spliting
        return Endpoint(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def addresses(self) -> pulumi.Output[Sequence['outputs.EndpointAddress']]:
        return pulumi.get(self, "addresses")

    @property
    @pulumi.getter(name="autoAddNewNodes")
    def auto_add_new_nodes(self) -> pulumi.Output[builtins.bool]:
        """
        当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        """
        return pulumi.get(self, "auto_add_new_nodes")

    @property
    @pulumi.getter(name="connectAllSlaveNodes")
    def connect_all_slave_nodes(self) -> pulumi.Output[builtins.bool]:
        """
        是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        """
        return pulumi.get(self, "connect_all_slave_nodes")

    @property
    @pulumi.getter(name="connectionInfoTags")
    def connection_info_tags(self) -> pulumi.Output[Sequence[builtins.str]]:
        """
        连接终端标签。
        """
        return pulumi.get(self, "connection_info_tags")

    @property
    @pulumi.getter(name="connectionMode")
    def connection_mode(self) -> pulumi.Output[builtins.str]:
        """
        连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        """
        return pulumi.get(self, "connection_mode")

    @property
    @pulumi.getter(name="connectionPoolType")
    def connection_pool_type(self) -> pulumi.Output[builtins.str]:
        """
        代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        """
        return pulumi.get(self, "connection_pool_type")

    @property
    @pulumi.getter(name="customRouteStrategy")
    def custom_route_strategy(self) -> pulumi.Output['outputs.EndpointCustomRouteStrategy']:
        """
        连接终端的 SQL 转发规则。
        """
        return pulumi.get(self, "custom_route_strategy")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[builtins.str]:
        """
        备注。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableConnectionPersistent")
    def enable_connection_persistent(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        """
        return pulumi.get(self, "enable_connection_persistent")

    @property
    @pulumi.getter(name="enableReadOnly")
    def enable_read_only(self) -> pulumi.Output[builtins.str]:
        """
        是否已开启全局只读，取值：Enable：开启。Disable：未开启。
        """
        return pulumi.get(self, "enable_read_only")

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> pulumi.Output[builtins.str]:
        """
        实例连接终端 ID。
        """
        return pulumi.get(self, "endpoint_id")

    @property
    @pulumi.getter(name="endpointName")
    def endpoint_name(self) -> pulumi.Output[builtins.str]:
        """
        实例连接终端名称。
        """
        return pulumi.get(self, "endpoint_name")

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> pulumi.Output[builtins.str]:
        """
        终端类型。取值为 Custom，自定义终端。
        """
        return pulumi.get(self, "endpoint_type")

    @property
    @pulumi.getter(name="idleConnectionReclaim")
    def idle_connection_reclaim(self) -> pulumi.Output[builtins.bool]:
        """
        空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "idle_connection_reclaim")

    @property
    @pulumi.getter(name="implicitTransSplit")
    def implicit_trans_split(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "implicit_trans_split")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[builtins.str]:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="masterNodeRouting")
    def master_node_routing(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_node_routing")

    @property
    @pulumi.getter(name="masterProtectorTimeout")
    def master_protector_timeout(self) -> pulumi.Output[builtins.int]:
        """
        过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_protector_timeout")

    @property
    @pulumi.getter(name="multiStatementsMode")
    def multi_statements_mode(self) -> pulumi.Output[builtins.str]:
        """
        代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        """
        return pulumi.get(self, "multi_statements_mode")

    @property
    @pulumi.getter
    def nodes(self) -> pulumi.Output[builtins.str]:
        """
        连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        """
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter(name="overloadProtection")
    def overload_protection(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "overload_protection")

    @property
    @pulumi.getter(name="readOnlyNodeDistributionType")
    def read_only_node_distribution_type(self) -> pulumi.Output[builtins.str]:
        """
        读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        """
        return pulumi.get(self, "read_only_node_distribution_type")

    @property
    @pulumi.getter(name="readOnlyNodeMaxDelayTime")
    def read_only_node_max_delay_time(self) -> pulumi.Output[builtins.int]:
        """
        只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        """
        return pulumi.get(self, "read_only_node_max_delay_time")

    @property
    @pulumi.getter(name="readOnlyNodeWeights")
    def read_only_node_weights(self) -> pulumi.Output[Sequence['outputs.EndpointReadOnlyNodeWeight']]:
        return pulumi.get(self, "read_only_node_weights")

    @property
    @pulumi.getter(name="readWriteMode")
    def read_write_mode(self) -> pulumi.Output[builtins.str]:
        """
        读写模式：ReadWrite：读写。ReadOnly：只读。
        """
        return pulumi.get(self, "read_write_mode")

    @property
    @pulumi.getter(name="readWriteSpliting")
    def read_write_spliting(self) -> pulumi.Output[builtins.bool]:
        """
        是否开启读写分离。取值：true：是。默认值。false：否。
        """
        return pulumi.get(self, "read_write_spliting")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import builtins
import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetEndpointResult',
    'AwaitableGetEndpointResult',
    'get_endpoint',
    'get_endpoint_output',
]

@pulumi.output_type
class GetEndpointResult:
    """
    A collection of values returned by getEndpoint.
    """
    def __init__(__self__, addresses=None, auto_add_new_nodes=None, connect_all_slave_nodes=None, connection_info_tags=None, connection_mode=None, connection_pool_type=None, custom_route_strategy=None, description=None, enable_connection_persistent=None, enable_read_only=None, endpoint_id=None, endpoint_name=None, endpoint_type=None, id=None, idle_connection_reclaim=None, implicit_trans_split=None, instance_id=None, master_node_routing=None, master_protector_timeout=None, multi_statements_mode=None, nodes=None, overload_protection=None, read_only_node_distribution_type=None, read_only_node_max_delay_time=None, read_only_node_weights=None, read_write_mode=None, read_write_spliting=None):
        if addresses and not isinstance(addresses, list):
            raise TypeError("Expected argument 'addresses' to be a list")
        pulumi.set(__self__, "addresses", addresses)
        if auto_add_new_nodes and not isinstance(auto_add_new_nodes, bool):
            raise TypeError("Expected argument 'auto_add_new_nodes' to be a bool")
        pulumi.set(__self__, "auto_add_new_nodes", auto_add_new_nodes)
        if connect_all_slave_nodes and not isinstance(connect_all_slave_nodes, bool):
            raise TypeError("Expected argument 'connect_all_slave_nodes' to be a bool")
        pulumi.set(__self__, "connect_all_slave_nodes", connect_all_slave_nodes)
        if connection_info_tags and not isinstance(connection_info_tags, list):
            raise TypeError("Expected argument 'connection_info_tags' to be a list")
        pulumi.set(__self__, "connection_info_tags", connection_info_tags)
        if connection_mode and not isinstance(connection_mode, str):
            raise TypeError("Expected argument 'connection_mode' to be a str")
        pulumi.set(__self__, "connection_mode", connection_mode)
        if connection_pool_type and not isinstance(connection_pool_type, str):
            raise TypeError("Expected argument 'connection_pool_type' to be a str")
        pulumi.set(__self__, "connection_pool_type", connection_pool_type)
        if custom_route_strategy and not isinstance(custom_route_strategy, dict):
            raise TypeError("Expected argument 'custom_route_strategy' to be a dict")
        pulumi.set(__self__, "custom_route_strategy", custom_route_strategy)
        if description and not isinstance(description, str):
            raise TypeError("Expected argument 'description' to be a str")
        pulumi.set(__self__, "description", description)
        if enable_connection_persistent and not isinstance(enable_connection_persistent, bool):
            raise TypeError("Expected argument 'enable_connection_persistent' to be a bool")
        pulumi.set(__self__, "enable_connection_persistent", enable_connection_persistent)
        if enable_read_only and not isinstance(enable_read_only, str):
            raise TypeError("Expected argument 'enable_read_only' to be a str")
        pulumi.set(__self__, "enable_read_only", enable_read_only)
        if endpoint_id and not isinstance(endpoint_id, str):
            raise TypeError("Expected argument 'endpoint_id' to be a str")
        pulumi.set(__self__, "endpoint_id", endpoint_id)
        if endpoint_name and not isinstance(endpoint_name, str):
            raise TypeError("Expected argument 'endpoint_name' to be a str")
        pulumi.set(__self__, "endpoint_name", endpoint_name)
        if endpoint_type and not isinstance(endpoint_type, str):
            raise TypeError("Expected argument 'endpoint_type' to be a str")
        pulumi.set(__self__, "endpoint_type", endpoint_type)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if idle_connection_reclaim and not isinstance(idle_connection_reclaim, bool):
            raise TypeError("Expected argument 'idle_connection_reclaim' to be a bool")
        pulumi.set(__self__, "idle_connection_reclaim", idle_connection_reclaim)
        if implicit_trans_split and not isinstance(implicit_trans_split, bool):
            raise TypeError("Expected argument 'implicit_trans_split' to be a bool")
        pulumi.set(__self__, "implicit_trans_split", implicit_trans_split)
        if instance_id and not isinstance(instance_id, str):
            raise TypeError("Expected argument 'instance_id' to be a str")
        pulumi.set(__self__, "instance_id", instance_id)
        if master_node_routing and not isinstance(master_node_routing, bool):
            raise TypeError("Expected argument 'master_node_routing' to be a bool")
        pulumi.set(__self__, "master_node_routing", master_node_routing)
        if master_protector_timeout and not isinstance(master_protector_timeout, int):
            raise TypeError("Expected argument 'master_protector_timeout' to be a int")
        pulumi.set(__self__, "master_protector_timeout", master_protector_timeout)
        if multi_statements_mode and not isinstance(multi_statements_mode, str):
            raise TypeError("Expected argument 'multi_statements_mode' to be a str")
        pulumi.set(__self__, "multi_statements_mode", multi_statements_mode)
        if nodes and not isinstance(nodes, str):
            raise TypeError("Expected argument 'nodes' to be a str")
        pulumi.set(__self__, "nodes", nodes)
        if overload_protection and not isinstance(overload_protection, bool):
            raise TypeError("Expected argument 'overload_protection' to be a bool")
        pulumi.set(__self__, "overload_protection", overload_protection)
        if read_only_node_distribution_type and not isinstance(read_only_node_distribution_type, str):
            raise TypeError("Expected argument 'read_only_node_distribution_type' to be a str")
        pulumi.set(__self__, "read_only_node_distribution_type", read_only_node_distribution_type)
        if read_only_node_max_delay_time and not isinstance(read_only_node_max_delay_time, int):
            raise TypeError("Expected argument 'read_only_node_max_delay_time' to be a int")
        pulumi.set(__self__, "read_only_node_max_delay_time", read_only_node_max_delay_time)
        if read_only_node_weights and not isinstance(read_only_node_weights, list):
            raise TypeError("Expected argument 'read_only_node_weights' to be a list")
        pulumi.set(__self__, "read_only_node_weights", read_only_node_weights)
        if read_write_mode and not isinstance(read_write_mode, str):
            raise TypeError("Expected argument 'read_write_mode' to be a str")
        pulumi.set(__self__, "read_write_mode", read_write_mode)
        if read_write_spliting and not isinstance(read_write_spliting, bool):
            raise TypeError("Expected argument 'read_write_spliting' to be a bool")
        pulumi.set(__self__, "read_write_spliting", read_write_spliting)

    @property
    @pulumi.getter
    def addresses(self) -> Sequence['outputs.GetEndpointAddressResult']:
        """
        终端节点地址列表。
        """
        return pulumi.get(self, "addresses")

    @property
    @pulumi.getter(name="autoAddNewNodes")
    def auto_add_new_nodes(self) -> builtins.bool:
        """
        当终端类型为读写终端或只读终端时，支持设置新节点是否自动加入。取值：true：自动加入。false：不自动加入（默认）。
        """
        return pulumi.get(self, "auto_add_new_nodes")

    @property
    @pulumi.getter(name="connectAllSlaveNodes")
    def connect_all_slave_nodes(self) -> builtins.bool:
        """
        是否关联所有的备节点。取值：true：是。默认值。false：否。说明仅多节点实例的只读终端支持该配置。仅在实例有两个或更多备节点时才能关闭此功能。
        """
        return pulumi.get(self, "connect_all_slave_nodes")

    @property
    @pulumi.getter(name="connectionInfoTags")
    def connection_info_tags(self) -> Sequence[builtins.str]:
        """
        连接终端标签。
        """
        return pulumi.get(self, "connection_info_tags")

    @property
    @pulumi.getter(name="connectionMode")
    def connection_mode(self) -> builtins.str:
        """
        连接终端类型。取值：Proxy：代理终端。Direct：直连终端。说明如实例的数据库代理功能已开启，可以取值为 Proxy 或 Direct。如实例的数据库代理功能未开启，仅可以取值为 Direct。可调用 DescribeDBInstanceDetail 接口查询实例数据库代理功能的开启状态。
        """
        return pulumi.get(self, "connection_mode")

    @property
    @pulumi.getter(name="connectionPoolType")
    def connection_pool_type(self) -> builtins.str:
        """
        代理终端的连接池类型。取值：Transaction：事务级连接池。默认值。Direct：直连模式。说明单节点实例不支持该功能。
        """
        return pulumi.get(self, "connection_pool_type")

    @property
    @pulumi.getter(name="customRouteStrategy")
    def custom_route_strategy(self) -> 'outputs.GetEndpointCustomRouteStrategyResult':
        """
        连接终端的 SQL 转发规则。
        """
        return pulumi.get(self, "custom_route_strategy")

    @property
    @pulumi.getter
    def description(self) -> builtins.str:
        """
        备注。
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableConnectionPersistent")
    def enable_connection_persistent(self) -> builtins.bool:
        """
        是否开启连接终端的连接保持功能。取值：true：是。false：否。说明仅代理终端支持该设置。
        """
        return pulumi.get(self, "enable_connection_persistent")

    @property
    @pulumi.getter(name="enableReadOnly")
    def enable_read_only(self) -> builtins.str:
        """
        是否已开启全局只读，取值：Enable：开启。Disable：未开启。
        """
        return pulumi.get(self, "enable_read_only")

    @property
    @pulumi.getter(name="endpointId")
    def endpoint_id(self) -> builtins.str:
        """
        实例连接终端 ID。
        """
        return pulumi.get(self, "endpoint_id")

    @property
    @pulumi.getter(name="endpointName")
    def endpoint_name(self) -> builtins.str:
        """
        实例连接终端名称。
        """
        return pulumi.get(self, "endpoint_name")

    @property
    @pulumi.getter(name="endpointType")
    def endpoint_type(self) -> builtins.str:
        """
        终端类型。取值为 Custom，自定义终端。
        """
        return pulumi.get(self, "endpoint_type")

    @property
    @pulumi.getter
    def id(self) -> builtins.str:
        """
        Uniquely identifies the resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="idleConnectionReclaim")
    def idle_connection_reclaim(self) -> builtins.bool:
        """
        空闲连接回收功能是否开启。true：开启。false：不开启。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "idle_connection_reclaim")

    @property
    @pulumi.getter(name="implicitTransSplit")
    def implicit_trans_split(self) -> builtins.bool:
        """
        是否开启事务分离。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "implicit_trans_split")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> builtins.str:
        """
        实例 ID。
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="masterNodeRouting")
    def master_node_routing(self) -> builtins.bool:
        """
        是否开启主节点路由。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_node_routing")

    @property
    @pulumi.getter(name="masterProtectorTimeout")
    def master_protector_timeout(self) -> builtins.int:
        """
        过载保护超时时间。取值范围为 60~7200 之间的整数，单位为秒。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "master_protector_timeout")

    @property
    @pulumi.getter(name="multiStatementsMode")
    def multi_statements_mode(self) -> builtins.str:
        """
        代理终端的 Multi-Statements 模式。取值：Strict：Strict 模式。默认值。Loose：Loose 模式。
        """
        return pulumi.get(self, "multi_statements_mode")

    @property
    @pulumi.getter
    def nodes(self) -> builtins.str:
        """
        连接终端配置的节点 ID 列表。当 EndpointType 为 Custom 时必选。说明如需将主节点加入终端，不需填写主节点 ID，只需填写 Primary。多个节点 ID 之间用英文逗号（,）分隔。
        """
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter(name="overloadProtection")
    def overload_protection(self) -> builtins.bool:
        """
        是否开启过载保护。取值：true：是。false：否。说明仅代理终端会返回该字段。
        """
        return pulumi.get(self, "overload_protection")

    @property
    @pulumi.getter(name="readOnlyNodeDistributionType")
    def read_only_node_distribution_type(self) -> builtins.str:
        """
        读权重分配模式。当开通读写分离设置为 true 时需要传入此参数。在 CreateDBEndpoint 和 ModifyDBEndpoint 接口中做请求参数时，取值范围如下：LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。在 DescribeDBInstanceDetail 接口中做返回参数时，取值范围如下：Default：按规格权重自动分配。Custom：自定义分配权重。RoundRobin：轮询调度。LoadSchedule：负载调度。RoundRobinCustom：自定义权重的轮询调度。RoundRobinAuto：自动分配权重的轮询调度。
        """
        return pulumi.get(self, "read_only_node_distribution_type")

    @property
    @pulumi.getter(name="readOnlyNodeMaxDelayTime")
    def read_only_node_max_delay_time(self) -> builtins.int:
        """
        只读节点延迟阈值。取值范围为 1~3600，默认为 30，单位为秒。
        """
        return pulumi.get(self, "read_only_node_max_delay_time")

    @property
    @pulumi.getter(name="readOnlyNodeWeights")
    def read_only_node_weights(self) -> Sequence['outputs.GetEndpointReadOnlyNodeWeightResult']:
        """
        连接终端配置的节点列表及对应的只读权重。
        """
        return pulumi.get(self, "read_only_node_weights")

    @property
    @pulumi.getter(name="readWriteMode")
    def read_write_mode(self) -> builtins.str:
        """
        读写模式：ReadWrite：读写。ReadOnly：只读。
        """
        return pulumi.get(self, "read_write_mode")

    @property
    @pulumi.getter(name="readWriteSpliting")
    def read_write_spliting(self) -> builtins.bool:
        """
        是否开启读写分离。取值：true：是。默认值。false：否。
        """
        return pulumi.get(self, "read_write_spliting")


class AwaitableGetEndpointResult(GetEndpointResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEndpointResult(
            addresses=self.addresses,
            auto_add_new_nodes=self.auto_add_new_nodes,
            connect_all_slave_nodes=self.connect_all_slave_nodes,
            connection_info_tags=self.connection_info_tags,
            connection_mode=self.connection_mode,
            connection_pool_type=self.connection_pool_type,
            custom_route_strategy=self.custom_route_strategy,
            description=self.description,
            enable_connection_persistent=self.enable_connection_persistent,
            enable_read_only=self.enable_read_only,
            endpoint_id=self.endpoint_id,
            endpoint_name=self.endpoint_name,
            endpoint_type=self.endpoint_type,
            id=self.id,
            idle_connection_reclaim=self.idle_connection_reclaim,
            implicit_trans_split=self.implicit_trans_split,
            instance_id=self.instance_id,
            master_node_routing=self.master_node_routing,
            master_protector_timeout=self.master_protector_timeout,
            multi_statements_mode=self.multi_statements_mode,
            nodes=self.nodes,
            overload_protection=self.overload_protection,
            read_only_node_distribution_type=self.read_only_node_distribution_type,
            read_only_node_max_delay_time=self.read_only_node_max_delay_time,
            read_only_node_weights=self.read_only_node_weights,
            read_write_mode=self.read_write_mode,
            read_write_spliting=self.read_write_spliting)


def get_endpoint(id: Optional[builtins.str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEndpointResult:
    """
    Data Source schema for Byteplus::RDSMySQL::Endpoint


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('bytepluscc:rdsmysql/getEndpoint:getEndpoint', __args__, opts=opts, typ=GetEndpointResult).value

    return AwaitableGetEndpointResult(
        addresses=pulumi.get(__ret__, 'addresses'),
        auto_add_new_nodes=pulumi.get(__ret__, 'auto_add_new_nodes'),
        connect_all_slave_nodes=pulumi.get(__ret__, 'connect_all_slave_nodes'),
        connection_info_tags=pulumi.get(__ret__, 'connection_info_tags'),
        connection_mode=pulumi.get(__ret__, 'connection_mode'),
        connection_pool_type=pulumi.get(__ret__, 'connection_pool_type'),
        custom_route_strategy=pulumi.get(__ret__, 'custom_route_strategy'),
        description=pulumi.get(__ret__, 'description'),
        enable_connection_persistent=pulumi.get(__ret__, 'enable_connection_persistent'),
        enable_read_only=pulumi.get(__ret__, 'enable_read_only'),
        endpoint_id=pulumi.get(__ret__, 'endpoint_id'),
        endpoint_name=pulumi.get(__ret__, 'endpoint_name'),
        endpoint_type=pulumi.get(__ret__, 'endpoint_type'),
        id=pulumi.get(__ret__, 'id'),
        idle_connection_reclaim=pulumi.get(__ret__, 'idle_connection_reclaim'),
        implicit_trans_split=pulumi.get(__ret__, 'implicit_trans_split'),
        instance_id=pulumi.get(__ret__, 'instance_id'),
        master_node_routing=pulumi.get(__ret__, 'master_node_routing'),
        master_protector_timeout=pulumi.get(__ret__, 'master_protector_timeout'),
        multi_statements_mode=pulumi.get(__ret__, 'multi_statements_mode'),
        nodes=pulumi.get(__ret__, 'nodes'),
        overload_protection=pulumi.get(__ret__, 'overload_protection'),
        read_only_node_distribution_type=pulumi.get(__ret__, 'read_only_node_distribution_type'),
        read_only_node_max_delay_time=pulumi.get(__ret__, 'read_only_node_max_delay_time'),
        read_only_node_weights=pulumi.get(__ret__, 'read_only_node_weights'),
        read_write_mode=pulumi.get(__ret__, 'read_write_mode'),
        read_write_spliting=pulumi.get(__ret__, 'read_write_spliting'))
def get_endpoint_output(id: Optional[pulumi.Input[builtins.str]] = None,
                        opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetEndpointResult]:
    """
    Data Source schema for Byteplus::RDSMySQL::Endpoint


    :param builtins.str id: Uniquely identifies the resource.
    """
    __args__ = dict()
    __args__['id'] = id
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('bytepluscc:rdsmysql/getEndpoint:getEndpoint', __args__, opts=opts, typ=GetEndpointResult)
    return __ret__.apply(lambda __response__: GetEndpointResult(
        addresses=pulumi.get(__response__, 'addresses'),
        auto_add_new_nodes=pulumi.get(__response__, 'auto_add_new_nodes'),
        connect_all_slave_nodes=pulumi.get(__response__, 'connect_all_slave_nodes'),
        connection_info_tags=pulumi.get(__response__, 'connection_info_tags'),
        connection_mode=pulumi.get(__response__, 'connection_mode'),
        connection_pool_type=pulumi.get(__response__, 'connection_pool_type'),
        custom_route_strategy=pulumi.get(__response__, 'custom_route_strategy'),
        description=pulumi.get(__response__, 'description'),
        enable_connection_persistent=pulumi.get(__response__, 'enable_connection_persistent'),
        enable_read_only=pulumi.get(__response__, 'enable_read_only'),
        endpoint_id=pulumi.get(__response__, 'endpoint_id'),
        endpoint_name=pulumi.get(__response__, 'endpoint_name'),
        endpoint_type=pulumi.get(__response__, 'endpoint_type'),
        id=pulumi.get(__response__, 'id'),
        idle_connection_reclaim=pulumi.get(__response__, 'idle_connection_reclaim'),
        implicit_trans_split=pulumi.get(__response__, 'implicit_trans_split'),
        instance_id=pulumi.get(__response__, 'instance_id'),
        master_node_routing=pulumi.get(__response__, 'master_node_routing'),
        master_protector_timeout=pulumi.get(__response__, 'master_protector_timeout'),
        multi_statements_mode=pulumi.get(__response__, 'multi_statements_mode'),
        nodes=pulumi.get(__response__, 'nodes'),
        overload_protection=pulumi.get(__response__, 'overload_protection'),
        read_only_node_distribution_type=pulumi.get(__response__, 'read_only_node_distribution_type'),
        read_only_node_max_delay_time=pulumi.get(__response__, 'read_only_node_max_delay_time'),
        read_only_node_weights=pulumi.get(__response__, 'read_only_node_weights'),
        read_write_mode=pulumi.get(__response__, 'read_write_mode'),
        read_write_spliting=pulumi.get(__response__, 'read_write_spliting')))
